fnss.topologies.parsers.parse_rocketfuel_isp_map — FNSS 0.1.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_rocketfuel_isp_map

`parse_rocketfuel_isp_map`(path)

  Parse a network topology from RocketFuel ISP map file.

  Parameters : | path : str The path of the file containing the RocketFuel map. It should have extension .cch
  Returns : | topology : DirectedTopology The object containing the parsed topology.
  Raises : | ValueError : If the provided file cannot be parsed correctly.

  Notes

  Each node of the returned graph has the following attributes:
    - type: string
    - location: string (optional)
    - address: string
    - r: int
    - backbone: boolean (optional)
  Each edge of the returned graph has the following attributes:
    - type : string, which can either be internal or external

  If the topology contains self-loops (links starting and ending in the same node) they are stripped from the topology.

  Examples

      >>> import fnss
      >>> topology = fnss.parse_rocketfuel_isp_map('1221.r0.cch')

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.1.2 documentation »
- API Reference »
- Functions »